# rmtoo-art-xml1

NAME
DESCRIPTION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-art-xml1 - requirements management tool: xml1 output

## DESCRIPTION

This is an experimental output module which converts mostly all input data to an XML file. This data can be then converted by e.g. XSLT.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later